@@ -1,4 +1,4 @@
-#' Validate verbose parameter and handle backward compatibility
+#' Validate Verbose Parameter and Handle Backward Compatibility
 #'
 #' @param verbose The verbose parameter value to validate
 #' @return A single non-negative integer
@@ -29,7 +29,7 @@
   verbose
 }
 
-#' Parse Nix build output to track derivation progress
+#' Parse Nix Build Output to Track Derivation Progress
 #'
 #' @param line Output line from nix-store
 #' @param derivation_names Vector of derivation names to track
@@ -114,7 +114,7 @@
   return(NULL)
 }
 
-#' Prepare nix-store command arguments
+#' Prepare nix-store Command Arguments
 #'
 #' @param max_jobs Integer, number of derivations to be built in parallel
 #' @param cores Integer, number of cores a derivation can use during build
@@ -154,6 +154,12 @@
 #'   Each level adds one --verbose flag to nix-store command.
 #' @param max_jobs Integer, number of derivations to be built in parallel.
 #' @param cores Integer, number of cores a derivation can use during build.
+#' @details
+#' When the `{chronicler}` package is available, `rxp_make()` automatically
+#' calls `rxp_check_chronicles()` after a successful build to check for
+#' `Nothing` values in chronicle objects. This helps detect silent failures
+#' in pipelines that use chronicler's `record()` decorated functions.
+#' See `vignette("chronicler")` for more details.
 #' @importFrom processx run
 #' @importFrom utils capture.output
 #' @return A character vector of paths to the built outputs.
@@ -387,12 +393,21 @@ rxp_make <- function(verbose = 0L, max_jobs = 1, cores = 1) {
       "Use `rxp_read(\"derivation_name\")` to read objects or\n",
       "`rxp_load(\"derivation_name\")` to load them into the global environment."
     )
+
+    # Automatically check for chronicle Nothing values if chronicler is available
+    if (.rxp_has_chronicler()) {
+      message(
+        "\nThis pipeline uses {chronicler}. ",
+        "Here is a summary of chronicle results:"
+      )
+      rxp_check_chronicles()
+    }
   }
 
   invisible(build_log)
 }
 
-#' Export Nix store paths to an archive
+#' Export Nix Store Paths to an Archive
 #'
 #' Creates a single archive file containing the specified Nix store paths
 #'   and their dependencies.
@@ -461,7 +476,7 @@ rxp_export_artifacts <- function(
   message("Export completed")
 }
 
-#' Import Nix store paths from an archive
+#' Import Nix Store Paths from an Archive
 #'
 #' Imports the store paths contained in an archive file into the local Nix store.
 #' Useful for transferring built outputs between machines.
